# 房屋管理功能需求说明

## 通用操作

* 移到回收站：将数据移动到回收站，数据可恢复。仅限操作正常状态的数据。

* 删除：将回收站的数据删除，删除后，数据不可恢复。（软删除）

* 恢复：将回收站的数据恢复到正常状态。

## 名词定义

| 名称  | 定义                                                             |
|:---:| -------------------------------------------------------------- |
| 小区  | 小区，是指在城市一定区域内、具有相对独立居住环境的大片居民住宅，同时是配有成套的生活服务设施，如商业网点、学校（幼儿园）等。 |
| 楼栋  | 小区内居民居住或商铺使用的具有唯一编号的独立建筑物。                                     |
| 单元  | 按照出入口将楼栋划分成一个或多个部分进行管理的建筑物                                     |
| 房屋  | 房屋是住人或存放东西的建筑物。房屋是家庭的基体                                        |

## 小区管理

小区管理功能用于物业客户在平台上数字化管理其管辖的小区信息，包括小区信息查看，添加，编辑，删除等操作。

### 表单字段说明

| 字段名称   | 字段类型   | 备注                                                                                      | 是否必填 |
| ------ | ------ | --------------------------------------------------------------------------------------- | ---- |
| 小区名称   | String | 在所属城市名称是__唯一__的，一般是根据开发商的楼盘名称设置。                                                        | 是    |
| 所属公司   | Int    | 关联管辖该小区的物业公司ID，对于集团公司而言，可能是总公司，也可能是分公司。                                                 | 是    |
| 所属管理处  | Int    | 关联管辖该小区的物业管理处ID，其中物业管理处属于小区所属公司的下级部门。                                                   | 否    |
| 所在省份   | Int    | 小区所在的省份的ID                                                                              | 是    |
| 所在城市   | Int    | 小区所在的城市的ID，该城市属于小区所在省份的下级                                                               | 是    |
| 所在地区   | Int    | 小区所在地区的ID，该地区行政级别对于城市为地级市的为区县级别，对于县级市的为乡镇级别                                             | 是    |
| 详细地址   | String | 小区所在街道，门牌编号等信息，通过百度地图定位后再填写                                                             | 是    |
| 经度     | Float  | 小区地理位置的百度地图经度坐标，精确度保留6位小数，坐标类型为BD09                                                     | 是    |
| 纬度     | Float  | 小区地理位置的百度地图纬度坐标，精确度保留6位小数，坐标类型为BD09                                                     | 是    |
| 物业类型   | Enum   | 枚举类型，可多选。包括住宅，别墅，公寓，写字楼，办公楼，厂房，医院，酒店，学校。                                                | 否    |
| Logo   | Image  | 小区Logo图片，尺寸为320 x 320像素，前端裁剪完再上传。上传格式支持jpg，jpeg，png。上传文件大小限制为1MB。                       | 否    |
| Banner | Image  | 小区Banner展示图，用于微信关注推送时首条消息的图片展示，尺寸为900 x 500像素，前端裁剪完再上传。上传格式支持jpg，jpeg，png。上传文件大小限制为1MB。 |      |
| 备注     | String | 不超过200个字符，对小区的一些额外补充信息。                                                                 | 否    |
| 详细介绍   | Text   | 小区图文介绍，用于C端用户了解小区信息                                                                     | 是    |

### 业务说明

* 可见状态：小区创建后，未保证功能可用性和数据的准确性，可见状态为`false`，即对C端用户是隐藏的。小区最终由平台管理方决定该小区是否对住户开放。

* 数据状态：小区的数据状态包括正常，回收站和已删除；其中回收站的小区可以恢复到正常状态，也可以删除（软删除，但不可恢复）。新建的小区默认是正常状态。

* 上线状态：小区创建后默认为下线状态，即C端用户无法查看到小区。小区由平台管理方设置为上线。设置为上线后，需要经由平台操作方可下线。

* 唯一性约束：小区名称在所在城市要求是唯一的，包括正常状态和回收站的小区，但不包括已删除状态的小区。

* 排序：展示的小区列表按小区名称首字母升序排序，数据库需要存储小区名称的首字母和全拼拼音（均为大写字母）。

* 数据筛选：支持按小区名称模糊搜索，支持按公司、省份、城市，地区、物业类型进行筛选。

* 统计字段：小区主表中冗余下属楼栋数量，单元数量和房屋数量。

* 可编辑字段：小区上线后，只允许编辑Logo，Banner，备注，详细介绍等信息；未上线前可编辑全部信息。

## 楼栋管理

楼栋管理功能用于管理小区中的楼栋信息。

### 表单字段说明

| 字段名  | 字段类型   | 备注                        | 是否必填 |
| ---- | ------ | ------------------------- | ---- |
| 楼栋名称 | String | 所在小区唯一                    | 是    |
| 有无单元 | Bool   | 选择无时系统自动创建一个默认单元，单元名为：1单元 | 是    |

### 业务说明

* 可见状态：新建的楼栋默认是可见的，后台暂不开放可见性设置功能。

* 数据状态：楼栋的数据状态包括正常，回收站和已删除；其中回收站的楼栋可以恢复到正常状态，也可以删除（软删除，但不可恢复）。新建的楼栋默认是正常状态。

* 唯一性约束：楼栋名称要求在所在小区是唯一的（已删除的不算重复）。

* 排序：为保证楼栋排序按物理楼栋号升序，存储楼栋数据时，需要额外提取楼栋号，楼栋号提取规则如下：

  * 将特殊字符全部去掉（替换为''），如1#替换为1。

  * 楼栋名称全部是中文，则提取拼音的前三个字母作为排序号（不足三个字母的保留全部字母），如紫金阁，则排序号为ZIJ；

  * 楼栋名称有ASCII字符或阿拉伯数字的，提取ASCII码或数字作为排序号，保留三个字符，不足三个字符的前面补0，如A栋，则排序号取值为00A；1号楼取值为001。

* 统计字段：下属单元数，下属房屋数

* 数据筛选：支持按楼栋名称模糊搜索。

* 可编辑字段：楼栋名称。

### 单元管理

单元管理用于管理楼栋下的单元信息，需要注意的是有些楼栋没有单元概念，但为保证数据一致性，需要添加默认的单元，默认单元统一为1单元（楼栋无单元时，缴费通知单，收据等单据上，缴费记录等不显示单元名称）。
